@@ -1,18 +1,7 @@
 /*
- * Copyright 2016-2019 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2016 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef BALOODETECTOR_H
@@ -34,7 +23,7 @@ public:
 
     explicit BalooDetector(QObject *parent = nullptr);
 
-    bool balooAvailability() const;
+    [[nodiscard]] bool balooAvailability() const;
 
 Q_SIGNALS:
 
