@@ -39,7 +39,8 @@ public:
         V13 = 13,
         V14 = 14,
         V15 = 15,
-        V16 = 16, //Does not exist yet, for testing purpose only.
+        V16 = 16,
+        V17 = 17,
     };
 
     explicit DatabaseInterface(QObject *parent = nullptr);
@@ -150,6 +151,8 @@ public Q_SLOTS:
 
     void trackHasStartedPlaying(const QUrl &fileName, const QDateTime &time);
 
+    void trackHasFinishedPlaying(const QUrl &fileName, const QDateTime &time);
+
     void clearData();
 
     void removeRadio(qulonglong radioId);
@@ -292,7 +295,9 @@ private:
 
     QVariantList internalGetLatestFourCoversForArtist(const QString& artistName);
 
-    void updateTrackStatistics(const QUrl &fileName, const QDateTime &time);
+    void updateTrackStartedStatistics(const QUrl &fileName, const QDateTime &time);
+
+    void updateTrackFinishedStatistics(const QUrl &fileName, const QDateTime &time);
 
     void createDatabaseV9();
 
@@ -310,6 +315,8 @@ private:
 
     void upgradeDatabaseV16();
 
+    void upgradeDatabaseV17();
+
     void checkDatabaseSchema();
 
     void checkAlbumsTableSchema();
