@@ -10,6 +10,7 @@
 #include "mediaplaylist.h"
 #include "playListLogging.h"
 #include "elisa_settings.h"
+#include "config-upnp-qt.h"
 #include <QItemSelection>
 #include <QList>
 #include <QRandomGenerator>
@@ -18,8 +19,123 @@
 #include <QDir>
 #include <QMimeDatabase>
 
+#if KFKIO_FOUND
+#include <KIO/OpenUrlJob>
+#endif
+
 #include <algorithm>
 
+QList<QUrl> M3uPlaylistParser::fromPlaylist(const QUrl &fileName, const QByteArray &fileContent) {
+    Q_UNUSED(fileName);
+    QList<QUrl> result;
+
+    for (const QByteArray &l : fileContent.split('\n')) {
+        const QString &line = QString::fromUtf8(l);
+        if (!line.isEmpty() && !line.startsWith(QStringLiteral("#"))) {
+            const QUrl &url = line.contains(QStringLiteral("://")) ? QUrl(line) : QUrl::fromLocalFile(line);
+            result.append(url);
+        }
+    }
+
+    return result;
+}
+
+QString M3uPlaylistParser::toPlaylist(const QUrl &fileName, const QList<QString> &listOfUrls) {
+    Q_UNUSED(fileName);
+    QString result;
+
+    for (const QString &line : listOfUrls) {
+        if (!line.isEmpty()) {
+            result += line + QStringLiteral("\n");
+        }
+    }
+
+    return result;
+}
+
+QList<QUrl> PlsPlaylistParser::fromPlaylist(const QUrl &fileName, const QByteArray &fileContent) {
+    Q_UNUSED(fileName);
+    QList<QUrl> result;
+    for (const QByteArray &l : fileContent.split('\n')) {
+        const QString &line = QString::fromUtf8(l);
+        if (!line.isEmpty() && line.startsWith(QStringLiteral("File")) && line.contains(QStringLiteral("="))) {
+            int indexOfEquals = line.indexOf(QStringLiteral("="));
+            QString urlAsString = line.mid(indexOfEquals + QStringLiteral("=").length());
+            const QUrl &url = urlAsString.contains(QStringLiteral("://")) ? QUrl(urlAsString) : QUrl::fromLocalFile(urlAsString);
+            result.append(url);
+        }
+    }
+
+    return result;
+}
+
+QString PlsPlaylistParser::toPlaylist(const QUrl &fileName, const QList<QString> &listOfUrls) {
+    Q_UNUSED(fileName);
+    QString result = QStringLiteral(R"--([playlist]
+
+Version=2
+NumberOfEntries=%1
+)--").arg(listOfUrls.count());
+
+    // Sample:
+/*[playlist]
+
+Version=2
+NumberOfEntries=2
+
+File1=http://example.example:8068
+
+File2=example2.mp3
+*/
+
+    int counter=0;
+    for (const QString &line : listOfUrls) {
+        if (!line.isEmpty()) {
+            QString oneLine = QStringLiteral("\nFile%1=%2\n").arg(counter + 1).arg(line);
+            result += oneLine;
+            counter++;
+        }
+    }
+
+    return result;
+}
+
+QList<QUrl> PlaylistParser::fromPlaylist(const QUrl &fileName, const QByteArray &fileContent) {
+    QList<QUrl> result;
+
+    if (fileName.isValid() && !fileName.isEmpty()) {
+        auto mimeType = QMimeDatabase().mimeTypeForUrl(fileName);
+
+        if (mimeType.inherits(QStringLiteral("audio/x-scpls"))) {
+            PlsPlaylistParser plsPlaylistParser;
+            result = plsPlaylistParser.fromPlaylist(fileName, fileContent);
+        } else if (mimeType.name().contains(QStringLiteral("mpegurl"))) {
+            M3uPlaylistParser m3uPlaylistParser;
+            result = m3uPlaylistParser.fromPlaylist(fileName, fileContent);
+        }
+    }
+
+    return result;
+}
+
+QString PlaylistParser::toPlaylist(const QUrl &fileName, const QList<QString> &listOfUrls) {
+    QString result;
+
+    if (fileName.isValid() && !fileName.isEmpty()) {
+        auto mimeType = QMimeDatabase().mimeTypeForUrl(fileName);
+
+        if (mimeType.inherits(QStringLiteral("audio/x-scpls"))) {
+            PlsPlaylistParser plsPlaylistParser;
+            result = plsPlaylistParser.toPlaylist(fileName, listOfUrls);
+        } else if (mimeType.name().contains(QStringLiteral("mpegurl"))) {
+            M3uPlaylistParser m3uPlaylistParser;
+            result = m3uPlaylistParser.toPlaylist(fileName, listOfUrls);
+        }
+    }
+
+    return result;
+}
+
 class MediaPlayListProxyModelPrivate
 {
 public:
@@ -50,6 +166,10 @@ public:
 
     bool mShufflePlayList = false;
 
+    bool mPartiallyLoaded = false;
+
+    QUrl mLoadedPlayListUrl;
+
 };
 
 MediaPlayListProxyModel::MediaPlayListProxyModel(QObject *parent) : QAbstractProxyModel (parent),
@@ -667,6 +787,26 @@ void MediaPlayListProxyModel::determineAndNotifyPreviousAndNextTracks()
     }
 }
 
+int MediaPlayListProxyModel::indexForTrackUrl(const QUrl &url)
+{
+    for (int i = 0; i < rowCount(); ++i) {
+        const QUrl thisTrackUrl = data(index(i,0), MediaPlayList::ResourceRole).toUrl();
+        if (thisTrackUrl == url) {
+            return i;
+        }
+    }
+    return -1;
+}
+
+void MediaPlayListProxyModel::switchToTrackUrl(const QUrl &url, ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay)
+{
+    switchTo(indexForTrackUrl(url));
+
+    if (triggerPlay == ElisaUtils::TriggerPlay) {
+        Q_EMIT requestPlay();
+    }
+}
+
 void MediaPlayListProxyModel::clearPlayList()
 {
     if (rowCount() == 0) {
@@ -720,55 +860,66 @@ bool MediaPlayListProxyModel::savePlayList(const QUrl &fileName)
         return false;
     }
 
+    QList<QString> listOfFilePaths;
+
     if (Elisa::ElisaConfiguration::self()->alwaysUseAbsolutePlaylistPaths()) {
         for (int i = 0; i < rowCount(); ++i) {
             if (data(index(i,0), MediaPlayList::IsValidRole).toBool()) {
                 data(index(i,0), MediaPlayList::ResourceRole).toUrl();
-                outputFile.write(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile().toUtf8());
-                outputFile.write("\n");
+                listOfFilePaths.append(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile());
             }
         }
     } else {
-        QFileInfo playlistFile(fileName.toLocalFile());
-        QDir dir(playlistFile.absolutePath());
-
         for (int i = 0; i < rowCount(); ++i) {
             if (data(index(i,0), MediaPlayList::IsValidRole).toBool()) {
-                QFileInfo musicFile(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile());
-
-                if (musicFile.dir().path() == dir.absolutePath()) {
-                    outputFile.write(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile().toUtf8());
-                } else {
-                    outputFile.write(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile().toUtf8());
-                }
-                outputFile.write("\n");
+                listOfFilePaths.append(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile());
             }
         }
     }
 
+    PlaylistParser playlistParser;
+    QString fileContent = playlistParser.toPlaylist(fileName, listOfFilePaths);
+
+    outputFile.write(fileContent.toUtf8());
+
     return true;
 }
 
 void MediaPlayListProxyModel::loadPlayList(const QUrl &fileName)
 {
+    loadPlayList(fileName, ElisaUtils::ReplacePlayList, ElisaUtils::DoNotTriggerPlay);
+}
+
+void MediaPlayListProxyModel::loadPlayList(const QUrl &fileName,
+                                           ElisaUtils::PlayListEnqueueMode enqueueMode,
+                                           ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay)
+{
+    resetPartiallyLoaded();
+
     QFile inputFile(fileName.toLocalFile());
-    auto open = inputFile.open(QFile::ReadOnly);
+    bool open = inputFile.open(QFile::ReadOnly);
     if (!open) {
         Q_EMIT playListLoadFailed();
     }
-    const auto data = inputFile.readAll();
-    clearPlayList();
-    auto newTracks = DataTypes::EntryDataList{};
-    for (const auto &l : data.split('\n')) {
-        const auto &line = QString::fromUtf8(l);
-        const auto &url = line.startsWith(QStringLiteral("file:/")) ? QUrl(line) : QUrl::fromLocalFile(line);
-        newTracks.push_back({{{{DataTypes::ElementTypeRole, ElisaUtils::FileName},
-            {DataTypes::ResourceRole, url}}}, {}, {}});
+
+    const QByteArray fileContent = inputFile.readAll();
+
+    if (enqueueMode == ElisaUtils::ReplacePlayList) {
+        clearPlayList();
     }
-    enqueue(newTracks, ElisaUtils::ReplacePlayList, ElisaUtils::DoNotTriggerPlay);
+
+    d->mLoadedPlayListUrl = fileName;
+
+    DataTypes::EntryDataList newTracks;
+    QSet<QString> processedFiles{QFileInfo(inputFile).canonicalFilePath()};
+    loadLocalPlayList(newTracks, processedFiles, fileName, fileContent);
+
+    enqueue(newTracks, enqueueMode, triggerPlay);
 
     Q_EMIT persistentStateChanged();
     Q_EMIT playListLoaded();
+    Q_EMIT partiallyLoadedChanged();
+    Q_EMIT canOpenLoadedPlaylistChanged();
 }
 
 QVariantMap MediaPlayListProxyModel::persistentState() const
@@ -819,36 +970,135 @@ void MediaPlayListProxyModel::setPersistentState(const QVariantMap &persistentSt
     Q_EMIT persistentStateChanged();
 }
 
-void MediaPlayListProxyModel::enqueueDirectory(const QUrl &fileName, ElisaUtils::PlayListEntryType databaseIdType,
-                                            ElisaUtils::PlayListEnqueueMode enqueueMode,
-                                            ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay, int depth)
+bool MediaPlayListProxyModel::partiallyLoaded() const
 {
-    if (!fileName.isLocalFile()) return;
-    // clear playlist if required
-    if (enqueueMode == ElisaUtils::ReplacePlayList) {
-        if (rowCount() != 0) {
-            clearPlayList();
+    return d->mPartiallyLoaded;
+}
+
+bool MediaPlayListProxyModel::canOpenLoadedPlaylist() const
+{
+#if !KFKIO_FOUND
+    return false;
+#endif
+    return d->mLoadedPlayListUrl.isValid() && d->mLoadedPlayListUrl.isLocalFile();
+}
+
+void MediaPlayListProxyModel::openLoadedPlayList()
+{
+#if KFKIO_FOUND
+    auto job = new KIO::OpenUrlJob(d->mLoadedPlayListUrl, QLatin1String("text/plain"));
+    job->start();
+#endif
+}
+
+void MediaPlayListProxyModel::resetPartiallyLoaded()
+{
+    d->mPartiallyLoaded = false;
+
+    Q_EMIT partiallyLoadedChanged();
+}
+
+void MediaPlayListProxyModel::loadLocalFile(DataTypes::EntryDataList &newTracks, QSet<QString> &processedFiles, const QFileInfo &fileInfo)
+{
+    // protection against recursion
+    auto canonicalFilePath = fileInfo.canonicalFilePath();
+    if (processedFiles.contains(canonicalFilePath)) {
+        return;
+    }
+    processedFiles.insert(canonicalFilePath);
+
+    auto fileUrl = QUrl::fromLocalFile(fileInfo.filePath());
+    auto mimeType = d->mMimeDb.mimeTypeForUrl(fileUrl);
+    if (fileInfo.isDir()) {
+        if (fileInfo.isSymLink()) {
+            return;
+        }
+        loadLocalDirectory(newTracks, processedFiles, fileUrl);
+    } else {
+        if (!mimeType.name().startsWith(QLatin1String("audio/"))) {
+            return;
+        }
+        if (ElisaUtils::isPlayList(mimeType)) {
+            QFile file(fileInfo.filePath());
+            if (!file.open(QIODevice::ReadOnly)) {
+                d->mPartiallyLoaded = true;
+                return;
+            }
+            loadLocalPlayList(newTracks, processedFiles, fileUrl, file.readAll());
+            return;
+        }
+        newTracks.push_back({{{DataTypes::ElementTypeRole, ElisaUtils::FileName}, {DataTypes::ResourceRole, fileUrl}}, {}, {}});
+    }
+}
+
+void MediaPlayListProxyModel::loadLocalPlayList(DataTypes::EntryDataList &newTracks,
+                                                QSet<QString> &processedFiles,
+                                                const QUrl &fileName,
+                                                const QByteArray &fileContent)
+{
+    PlaylistParser playlistParser;
+    QList<QUrl> listOfUrls = playlistParser.fromPlaylist(fileName, fileContent);
+
+    int filtered = filterLocalPlayList(listOfUrls, fileName);
+    if (filtered != 0) {
+        d->mPartiallyLoaded = true;
+    }
+
+    for (const QUrl &oneUrl : qAsConst(listOfUrls)) {
+        if (oneUrl.isLocalFile()) {
+            QFileInfo fileInfo(oneUrl.toLocalFile());
+            loadLocalFile(newTracks, processedFiles, fileInfo);
+        } else {
+            newTracks.push_back({{{{DataTypes::ElementTypeRole, ElisaUtils::FileName}, {DataTypes::ResourceRole, oneUrl}}}, {}, {}});
         }
     }
-    // get contents of directory
-    QDir dirInfo = QDir(fileName.toLocalFile());
-    auto files = dirInfo.entryInfoList(QDir::NoDotAndDotDot | QDir::Readable | QDir::Files | QDir::Dirs, QDir::Name);
-    auto newFiles = DataTypes::EntryDataList();
-    for (const auto &file : files)
-    {
-        auto fileUrl = QUrl::fromLocalFile(file.filePath());
-        if (file.isFile() && d->mMimeDb.mimeTypeForUrl(fileUrl).name().startsWith(QLatin1String("audio/")))
-        {
-            newFiles.push_back({{{DataTypes::ElementTypeRole, ElisaUtils::Track},
-                                 {DataTypes::ResourceRole, fileUrl}},{}, {}});
+}
+
+void MediaPlayListProxyModel::loadLocalDirectory(DataTypes::EntryDataList &newTracks, QSet<QString> &processedFiles, const QUrl &dirName)
+{
+    QDir dirInfo(dirName.toLocalFile());
+    auto fileInfoList = dirInfo.entryInfoList(QDir::NoDotAndDotDot | QDir::Readable | QDir::Files | QDir::Dirs, QDir::Name);
+
+    for (const auto &fileInfo : fileInfoList) {
+        loadLocalFile(newTracks, processedFiles, fileInfo);
+    }
+}
+
+int MediaPlayListProxyModel::filterLocalPlayList(QList<QUrl>& result, const QUrl &playlistUrl)
+{
+    int filtered = 0;
+
+    for (auto iterator = result.begin(); iterator != result.end();) {
+        bool exists = true;
+
+        auto &url = *iterator;
+        if (url.isLocalFile()) {
+            QString file = url.toLocalFile();
+
+            QFileInfo fileInfo(file);
+            if (playlistUrl.isLocalFile() && fileInfo.isRelative()) {
+                auto absoluteDir = QFileInfo(playlistUrl.toLocalFile()).absoluteDir();
+                if (fileInfo.isDir()) {
+                    file = absoluteDir.absolutePath() + QDir::separator() + fileInfo.path();
+                } else {
+                    file = absoluteDir.absoluteFilePath(file);
+                }
+                fileInfo.setFile(file);
+                url = QUrl::fromLocalFile(file);
+            }
+
+            exists = fileInfo.exists();
         }
-        else if (file.isDir() && depth > 1)
-        {
-            // recurse through directory
-            enqueueDirectory(fileUrl, databaseIdType, ElisaUtils::AppendPlayList, triggerPlay, depth-1);
+
+        if (exists) {
+            ++iterator;
+        } else {
+            ++filtered;
+            iterator = result.erase(iterator);
         }
     }
-    if (newFiles.size() != 0) enqueue(newFiles, ElisaUtils::AppendPlayList, triggerPlay);
+
+    return filtered;
 }
 
 #include "moc_mediaplaylistproxymodel.cpp"
