@@ -17,6 +17,8 @@
 #include <QRegularExpression>
 #include <QReadWriteLock>
 #include <QThreadPool>
+#include <QFuture>
+#include <QFutureWatcher>
 
 class MediaPlayListProxyModel;
 
@@ -69,11 +71,15 @@ public Q_SLOTS:
 
     void replaceAndPlayOfPlayList(const QModelIndex &rootIndex);
 
+    void replaceAndPlayOfPlayListFromTrackUrl(const QModelIndex &rootIndex, const QUrl &switchTrackUrl);
+
     void enqueue(const DataTypes::MusicDataType &newEntry,
                  const QString &newEntryTitle,
                  ElisaUtils::PlayListEnqueueMode enqueueMode,
                  ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
+    void afterPlaylistEnqueue();
+
 Q_SIGNALS:
 
     void filterTextChanged(const QString &filterText);
@@ -88,6 +94,8 @@ Q_SIGNALS:
                           ElisaUtils::PlayListEnqueueMode enqueueMode,
                           ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
+    void switchToTrackUrl(const QUrl &url, ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
+
 protected:
 
     [[nodiscard]] bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override = 0;
@@ -108,9 +116,14 @@ protected:
 
     MediaPlayListProxyModel* mPlayList = nullptr;
 
+    QFutureWatcher<void> mEnqueueWatcher;
+
+    QUrl mEnqueueWatcherTrackUrl;
+
+
 private:
 
-    void genericEnqueueToPlayList(const QModelIndex &rootIndex,
+    QFuture<void> genericEnqueueToPlayList(const QModelIndex &rootIndex,
                                   ElisaUtils::PlayListEnqueueMode enqueueMode,
                                   ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
