@@ -37,6 +37,9 @@ QVariant EditableTrackMetadataModel::data(const QModelIndex &index, int role) co
             case ElisaUtils::Radio:
                 result = false;
                 break;
+            case ElisaUtils::PlayList:
+                result = false;
+                break;
             case ElisaUtils::Album:
             case ElisaUtils::Artist:
             case ElisaUtils::Composer:
@@ -50,68 +53,29 @@ QVariant EditableTrackMetadataModel::data(const QModelIndex &index, int role) co
             }
             break;
         case DataTypes::ImageUrlRole:
-            result = false;
-            break;
         case DataTypes::ArtistRole:
-            result = false;
-            break;
         case DataTypes::AlbumRole:
-            result = false;
-            break;
         case DataTypes::AlbumArtistRole:
-            result = false;
-            break;
         case DataTypes::TrackNumberRole:
-            result = false;
-            break;
         case DataTypes::DiscNumberRole:
-            result = false;
-            break;
         case DataTypes::RatingRole:
-            result = false;
-            break;
         case DataTypes::GenreRole:
-            result = false;
-            break;
         case DataTypes::LyricistRole:
-            result = false;
-            break;
         case DataTypes::ComposerRole:
-            result = false;
-            break;
         case DataTypes::CommentRole:
-            result = false;
-            break;
         case DataTypes::YearRole:
-            result = false;
-            break;
-        case DataTypes::LastPlayDate:
-            result = true;
-            break;
-        case DataTypes::PlayCounter:
-            result = true;
-            break;
         case DataTypes::LyricsRole:
             result = false;
             break;
+        case DataTypes::LastPlayDate:
+        case DataTypes::PlayCounter:
         case DataTypes::DurationRole:
-            result = true;
-            break;
         case DataTypes::SampleRateRole:
-            result = false;
-            break;
         case DataTypes::BitRateRole:
-            result = false;
-            break;
         case DataTypes::ChannelsRole:
-            result = false;
-            break;
         case DataTypes::FirstPlayDate:
             result = true;
             break;
-        case DataTypes::PlayFrequency:
-            result = true;
-            break;
         case DataTypes::SecondaryTextRole:
         case DataTypes::ShadowForImageRole:
         case DataTypes::ChildModelRole:
@@ -133,6 +97,8 @@ QVariant EditableTrackMetadataModel::data(const QModelIndex &index, int role) co
         case DataTypes::IsDirectoryRole:
         case DataTypes::IsPlayListRole:
         case DataTypes::FilePathRole:
+        case DataTypes::HasChildrenRole:
+        case DataTypes::MultipleImageUrlsRole:
             break;
         }
         break;
@@ -181,13 +147,14 @@ QVariant EditableTrackMetadataModel::data(const QModelIndex &index, int role) co
             case DataTypes::HasEmbeddedCover:
             case DataTypes::FileModificationTime:
             case DataTypes::FirstPlayDate:
-            case DataTypes::PlayFrequency:
             case DataTypes::ElementTypeRole:
             case DataTypes::FullDataRole:
             case DataTypes::IsDirectoryRole:
             case DataTypes::IsPlayListRole:
             case DataTypes::FilePathRole:
             case DataTypes::ResourceRole:
+            case DataTypes::HasChildrenRole:
+            case DataTypes::MultipleImageUrlsRole:
                 result = false;
                 break;
             }
@@ -201,6 +168,7 @@ QVariant EditableTrackMetadataModel::data(const QModelIndex &index, int role) co
         case ElisaUtils::Genre:
         case ElisaUtils::Lyricist:
         case ElisaUtils::Unknown:
+        case ElisaUtils::PlayList:
             result = false;
             break;
         }
