@@ -16,14 +16,18 @@
 #include "managemediaplayercontrol.h"
 #include "manageheaderbar.h"
 #include "audiowrapper.h"
+#include <kfilemetadata/extractorcollection.h>
 
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+#if KFFileMetaData_FOUND
+#include <KFileMetaData/ExtractorCollection>
+#include <KFileMetaData/Extractor>
+#include <KFileMetaData/SimpleExtractionResult>
 #include <KFileMetaData/EmbeddedImageData>
+#include <QMimeDatabase>
 #endif
 
 #include <QCryptographicHash>
 #include <QStringList>
-#include <QDBusMessage>
 #include <QDBusConnection>
 
 
@@ -64,6 +68,10 @@ MediaPlayer2Player::MediaPlayer2Player(MediaPlayListProxyModel *playListControle
             this, &MediaPlayer2Player::audioDurationChanged);
     connect(m_audioPlayer, &AudioWrapper::volumeChanged,
             this, &MediaPlayer2Player::playerVolumeChanged);
+    connect(m_playListControler, &MediaPlayListProxyModel::shufflePlayListChanged,
+            this, &MediaPlayer2Player::shufflePlayListChanged);
+    connect(m_playListControler, &MediaPlayListProxyModel::repeatModeChanged,
+            this, &MediaPlayer2Player::repeatModeChanged);
 
     m_volume = m_audioPlayer->volume() / 100;
     m_canPlay = m_manageMediaPlayerControl->playControlEnabled();
@@ -416,10 +424,20 @@ QVariantMap MediaPlayer2Player::getMetadataOfCurrentTrack()
         if (m_manageHeaderBar->image().scheme() == QStringLiteral("image")) {
             // adding a special case for image:// URLs that are only valid because Elisa installs a special handler for them
             // converting those URL to data URLs with embedded image data
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
-            KFileMetaData::EmbeddedImageData embeddedImage;
+#if KFFileMetaData_FOUND
 
-            auto imageData = embeddedImage.imageData(m_manageHeaderBar->image().toString().mid(14));
+            const auto &mimeType = QMimeDatabase().mimeTypeForFile(m_manageHeaderBar->image().toString().mid(14)).name();
+            KFileMetaData::ExtractorCollection extractorCollection;
+            auto extractors = extractorCollection.fetchExtractors(mimeType);
+
+            QMap<KFileMetaData::EmbeddedImageData::ImageType, QByteArray> imageData;
+            for (const auto &extractor : extractors) {
+                KFileMetaData::SimpleExtractionResult result(m_manageHeaderBar->image().toString().mid(14), mimeType, KFileMetaData::ExtractionResult::ExtractImageData);
+                extractor->extract(&result);
+                if (!result.imageData().isEmpty()) {
+                    imageData = result.imageData();
+                }
+            }
 
             if (imageData.contains(KFileMetaData::EmbeddedImageData::FrontCover)) {
                 result[QStringLiteral("mpris:artUrl")] = QString{QStringLiteral("data:image/png;base64,") + QLatin1String{imageData[KFileMetaData::EmbeddedImageData::FrontCover].toBase64()}};
@@ -479,6 +497,69 @@ void MediaPlayer2Player::setMediaPlayerPresent(int status)
     }
 }
 
+void MediaPlayer2Player::setShuffle(bool shuffle)
+{
+    if (m_playListControler) {
+        m_playListControler->setShufflePlayList(shuffle);
+        signalPropertiesChange(QStringLiteral("Shuffle"), Shuffle());
+    }
+}
+
+bool MediaPlayer2Player::Shuffle() const
+{
+    if (m_playListControler) {
+        return m_playListControler->shufflePlayList();
+    }
+
+    return false;
+}
+
+void MediaPlayer2Player::shufflePlayListChanged()
+{
+    signalPropertiesChange(QStringLiteral("Shuffle"), Shuffle());
+}
+
+void MediaPlayer2Player::setLoopStatus(const QString& loopStatus)
+{
+    MediaPlayListProxyModel::Repeat repeatMode;
+
+    if (m_playListControler) {
+        if (loopStatus == QStringLiteral("Playlist")) {
+            repeatMode = MediaPlayListProxyModel::Playlist;
+        } else if (loopStatus == QStringLiteral("Track")) {
+            repeatMode = MediaPlayListProxyModel::One;
+        } else {
+            repeatMode = MediaPlayListProxyModel::None;
+        }
+
+        m_playListControler->setRepeatMode(repeatMode);
+        signalPropertiesChange(QStringLiteral("LoopStatus"), LoopStatus());
+    }
+}
+
+QString MediaPlayer2Player::LoopStatus() const
+{
+    if (m_playListControler) {
+        const auto repeatMode = m_playListControler->repeatMode();
+        switch (repeatMode) {
+            case MediaPlayListProxyModel::Playlist:
+                return QStringLiteral("Playlist");
+            case MediaPlayListProxyModel::One:
+                return QStringLiteral("Track");
+            case MediaPlayListProxyModel::None:
+            default:
+                return QStringLiteral("None");
+        }
+    }
+
+    return QStringLiteral("None");
+}
+
+void MediaPlayer2Player::repeatModeChanged()
+{
+    signalPropertiesChange(QStringLiteral("LoopStatus"), LoopStatus());
+}
+
 void MediaPlayer2Player::signalPropertiesChange(const QString &property, const QVariant &value)
 {
     QVariantMap properties;
