@@ -10,16 +10,16 @@
 
 #include "indexersManager.h"
 
-#if defined UPNPQT_FOUND && UPNPQT_FOUND
+#if UPNPQT_FOUND
 #include "upnp/upnplistener.h"
 #endif
 
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
 #include "baloo/baloolistener.h"
 #include "baloo/baloodetector.h"
 #endif
 
-#if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
+#if QtAndroidExtras_FOUND
 #include "android/androidmusiclistener.h"
 #endif
 
@@ -32,14 +32,13 @@
 #include "elisa_settings.h"
 #include "modeldataloader.h"
 
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 #include <QThread>
 #include <QStandardPaths>
 #include <QDir>
 #include <QCoreApplication>
 #include <QFileSystemWatcher>
-#include <QAction>
 
 #include <list>
 
@@ -51,11 +50,11 @@ public:
 
     QThread mListenerThread;
 
-#if defined UPNPQT_FOUND && UPNPQT_FOUND
+#if UPNPQT_FOUND
     UpnpListener mUpnpListener;
 #endif
 
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
     BalooDetector mBalooDetector;
 
     BalooListener mBalooListener;
@@ -63,8 +62,8 @@ public:
 
     FileListener mFileListener;
 
-#if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
-    std::unique_ptr<AndroidMusicListener> mAndroidMusicListener;
+#if QtAndroidExtras_FOUND
+    AndroidMusicListener mAndroidMusicListener;
 #endif
 
     DatabaseInterface mDatabaseInterface;
@@ -99,15 +98,17 @@ MusicListenersManager::MusicListenersManager(QObject *parent)
     connect(&d->mDatabaseInterface, &DatabaseInterface::tracksAdded,
             this, &MusicListenersManager::increaseImportedTracksCount);
 
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
     connect(&d->mBalooDetector, &BalooDetector::balooAvailabilityChanged,
             this, &MusicListenersManager::balooAvailabilityChanged);
 #endif
 
     connect(&d->mDatabaseInterface, &DatabaseInterface::requestsInitDone,
             this, &MusicListenersManager::databaseReady);
+
     connect(this, &MusicListenersManager::clearDatabase,
             &d->mDatabaseInterface, &DatabaseInterface::clearData);
+
     connect(&d->mDatabaseInterface, &DatabaseInterface::cleanedDatabase,
             this, &MusicListenersManager::cleanedDatabase);
 
@@ -117,6 +118,9 @@ MusicListenersManager::MusicListenersManager(QObject *parent)
     connect(&d->mConfigFileWatcher, &QFileSystemWatcher::fileChanged,
             this, &MusicListenersManager::configChanged);
 
+    connect(this, &MusicListenersManager::refreshDatabase,
+            &d->mDatabaseInterface, &DatabaseInterface::askRestoredTracks);
+
     d->mListenerThread.start();
     d->mDatabaseThread.start();
 
@@ -212,7 +216,7 @@ auto MusicListenersManager::initializeRootPath()
 {
     auto initialRootPath = QStringList{};
     auto systemMusicPaths = QStandardPaths::standardLocations(QStandardPaths::MusicLocation);
-    for (const auto &musicPath : qAsConst(systemMusicPaths)) {
+    for (const auto &musicPath : std::as_const(systemMusicPaths)) {
         initialRootPath.push_back(musicPath);
     }
 
@@ -247,13 +251,6 @@ void MusicListenersManager::applicationAboutToQuit()
     d->mListenerThread.wait();
 }
 
-void MusicListenersManager::showConfiguration()
-{
-    auto configureAction = d->mElisaApplication->action(QStringLiteral("options_configure"));
-
-    configureAction->trigger();
-}
-
 void MusicListenersManager::setElisaApplication(ElisaApplication *elisaApplication)
 {
     if (d->mElisaApplication == elisaApplication) {
@@ -261,7 +258,7 @@ void MusicListenersManager::setElisaApplication(ElisaApplication *elisaApplicati
     }
 
     d->mElisaApplication = elisaApplication;
-    emit elisaApplicationChanged();
+    Q_EMIT elisaApplicationChanged();
 }
 
 void MusicListenersManager::playBackError(const QUrl &sourceInError, QMediaPlayer::Error playerError)
@@ -296,6 +293,7 @@ void MusicListenersManager::deleteElementById(ElisaUtils::PlayListEntryType entr
     case ElisaUtils::FileName:
     case ElisaUtils::Unknown:
     case ElisaUtils::Container:
+    case ElisaUtils::PlayList:
         break;
     }
 }
@@ -305,9 +303,16 @@ void MusicListenersManager::connectModel(ModelDataLoader *dataLoader)
     dataLoader->moveToThread(&d->mDatabaseThread);
 }
 
-void MusicListenersManager::resetMusicData()
+void MusicListenersManager::scanCollection(CollectionScan scantype)
 {
-    Q_EMIT clearDatabase();
+    switch (scantype)
+    {
+    case CollectionScan::Hard:
+        Q_EMIT clearDatabase();
+        break;
+    case CollectionScan::Soft:
+        Q_EMIT refreshDatabase();
+    }
 }
 
 void MusicListenersManager::configChanged()
@@ -320,7 +325,7 @@ void MusicListenersManager::configChanged()
     currentConfiguration->read();
 
     bool configurationHasChanged = false;
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
     if (d->mBalooIndexerAvailable && d->mBalooIndexerActive && d->mBalooListener.canHandleRootPaths() && !currentConfiguration->forceUsageOfFastFileSearch()) {
         configurationHasChanged = true;
     } else if (d->mBalooIndexerAvailable && !d->mBalooIndexerActive && d->mBalooListener.canHandleRootPaths() && currentConfiguration->forceUsageOfFastFileSearch()) {
@@ -340,7 +345,7 @@ void MusicListenersManager::configChanged()
 
     //resolve symlinks
     QStringList allRootPaths;
-    for (const auto &onePath : qAsConst(inputRootPath)) {
+    for (const auto &onePath : std::as_const(inputRootPath)) {
         auto workPath = onePath;
         if (workPath.startsWith(QLatin1String("file:/"))) {
             auto urlPath = QUrl{workPath};
@@ -350,7 +355,11 @@ void MusicListenersManager::configChanged()
         QFileInfo pathFileInfo(workPath);
         auto directoryPath = pathFileInfo.canonicalFilePath();
         if (!directoryPath.isEmpty()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             if (directoryPath.rightRef(1) != QLatin1Char('/'))
+#else
+            if (QStringView(directoryPath).right(1) != QLatin1Char('/'))
+#endif
             {
                 directoryPath.append(QLatin1Char('/'));
             }
@@ -364,7 +373,7 @@ void MusicListenersManager::configChanged()
 
     d->mFileListener.setAllRootPaths(allRootPaths);
 
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
     d->mBalooListener.setAllRootPaths(allRootPaths);
 #endif
 
@@ -372,7 +381,7 @@ void MusicListenersManager::configChanged()
         testBalooIndexerAvailability();
     }
 
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
     if (d->mBalooIndexerAvailable && !d->mBalooIndexerActive && d->mBalooListener.canHandleRootPaths() && currentConfiguration->forceUsageOfFastFileSearch()) {
         qCDebug(orgKdeElisaIndexersManager()) << "trigger start of baloo file indexer";
         QMetaObject::invokeMethod(d->mFileListener.fileListing(), "stop", Qt::BlockingQueuedConnection);
@@ -391,34 +400,25 @@ void MusicListenersManager::configChanged()
 
     if (d->mBalooIndexerActive) {
         qCInfo(orgKdeElisaIndexersManager()) << "trigger init of baloo file indexer";
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
         QMetaObject::invokeMethod(d->mBalooListener.fileListing(), "init", Qt::QueuedConnection);
 #endif
     } else if (d->mFileSystemIndexerActive) {
         qCInfo(orgKdeElisaIndexersManager()) << "trigger init of local file indexer";
         QMetaObject::invokeMethod(d->mFileListener.fileListing(), "init", Qt::QueuedConnection);
+    } else if (d->mAndroidIndexerActive) {
+#if defined Q_OS_ANDROID
+        QMetaObject::invokeMethod(d->mAndroidMusicListener.fileListing(), "init", Qt::QueuedConnection);
+#endif
     }
 
-#if defined UPNPQT_FOUND && UPNPQT_FOUND
+#if UPNPQT_FOUND
     d->mUpnpListener.setDatabaseInterface(&d->mDatabaseInterface);
     d->mUpnpListener.moveToThread(&d->mDatabaseThread);
     connect(this, &MusicListenersManager::applicationIsTerminating,
             &d->mUpnpListener, &UpnpListener::applicationAboutToQuit, Qt::DirectConnection);
 #endif
 
-#if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
-    if (!d->mAndroidMusicListener) {
-        d->mAndroidMusicListener = std::make_unique<AndroidMusicListener>();
-        d->mAndroidMusicListener->moveToThread(&d->mListenerThread);
-        d->mAndroidMusicListener->setDatabaseInterface(&d->mDatabaseInterface);
-        connect(this, &MusicListenersManager::applicationIsTerminating,
-                d->mAndroidMusicListener.get(), &AndroidMusicListener::applicationAboutToQuit, Qt::DirectConnection);
-        connect(d->mAndroidMusicListener.get(), &AndroidMusicListener::indexingStarted,
-                this, &MusicListenersManager::monitorStartingListeners);
-        connect(d->mAndroidMusicListener.get(), &AndroidMusicListener::indexingFinished,
-                this, &MusicListenersManager::monitorEndingListeners);
-    }
-#endif
 }
 
 void MusicListenersManager::increaseImportedTracksCount(const DataTypes::ListTrackDataType &allTracks)
@@ -456,7 +456,7 @@ void MusicListenersManager::cleanedDatabase()
 
 void MusicListenersManager::balooAvailabilityChanged()
 {
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
     if (!d->mBalooDetector.balooAvailability() || !d->mBalooListener.canHandleRootPaths()) {
         if (d->mBalooDetector.balooAvailability()) {
             qCInfo(orgKdeElisaIndexersManager) << "Baloo indexer is available";
@@ -466,7 +466,7 @@ void MusicListenersManager::balooAvailabilityChanged()
     if (true) {
 #endif
 
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
         if (!d->mBalooListener.canHandleRootPaths() && d->mBalooDetector.balooAvailability())
         {
             qCInfo(orgKdeElisaIndexersManager()) << "Baloo cannot handle all configured paths: falling back to plain filex indexer";
@@ -476,6 +476,9 @@ void MusicListenersManager::balooAvailabilityChanged()
         if (!d->mFileSystemIndexerActive) {
             startLocalFileSystemIndexing();
         }
+        if (!d->mAndroidIndexerActive) {
+            startAndroidIndexing();
+        }
 
         return;
     }
@@ -488,7 +491,7 @@ void MusicListenersManager::balooAvailabilityChanged()
 
 void MusicListenersManager::testBalooIndexerAvailability()
 {
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
     d->mBalooDetector.checkBalooAvailability();
 #else
     qCInfo(orgKdeElisaIndexersManager) << "Baloo indexer is unavailable";
@@ -500,6 +503,7 @@ void MusicListenersManager::testBalooIndexerAvailability()
     Q_EMIT balooIndexerActiveChanged();
 
     startLocalFileSystemIndexing();
+    startAndroidIndexing();
 #endif
 }
 
@@ -524,9 +528,33 @@ void MusicListenersManager::startLocalFileSystemIndexing()
     Q_EMIT fileSystemIndexerActiveChanged();
 }
 
+void MusicListenersManager::startAndroidIndexing()
+{
+    qCInfo(orgKdeElisaIndexersManager) << "MusicListenersManager::startAndroidIndexing";
+#if defined Q_OS_ANDROID
+    if (d->mAndroidIndexerActive) {
+        return;
+    }
+
+    d->mAndroidMusicListener.setDatabaseInterface(&d->mDatabaseInterface);
+    d->mAndroidMusicListener.moveToThread(&d->mListenerThread);
+    connect(this, &MusicListenersManager::applicationIsTerminating,
+            &d->mAndroidMusicListener, &AndroidMusicListener::applicationAboutToQuit, Qt::DirectConnection);
+    connect(&d->mAndroidMusicListener, &AndroidMusicListener::indexingStarted,
+            this, &MusicListenersManager::monitorStartingListeners);
+    connect(&d->mAndroidMusicListener, &AndroidMusicListener::indexingFinished,
+            this, &MusicListenersManager::monitorEndingListeners);
+
+    qCInfo(orgKdeElisaIndexersManager) << "Android indexer is active";
+
+    d->mAndroidIndexerActive = true;
+    Q_EMIT androidIndexerActiveChanged();
+#endif
+}
+
 void MusicListenersManager::startBalooIndexing()
 {
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KFBaloo_FOUND
     d->mBalooListener.moveToThread(&d->mListenerThread);
     d->mBalooListener.setDatabaseInterface(&d->mDatabaseInterface);
     connect(this, &MusicListenersManager::applicationIsTerminating,
@@ -561,5 +589,9 @@ void MusicListenersManager::createTracksListener()
     }
 }
 
+void MusicListenersManager::updateSingleFileMetaData(const QUrl &url, DataTypes::ColumnsRoles role, const QVariant &data)
+{
+    tracksListener()->updateSingleFileMetaData(url, role, data);
+}
 
 #include "moc_musiclistenersmanager.cpp"
