@@ -72,6 +72,12 @@ class ELISALIB_EXPORT MusicListenersManager : public QObject
 
 public:
 
+    enum class CollectionScan {
+        Soft,
+        Hard,
+    };
+    Q_ENUM(CollectionScan)
+
     explicit MusicListenersManager(QObject *parent = nullptr);
 
     ~MusicListenersManager() override;
@@ -130,14 +136,14 @@ Q_SIGNALS:
 
     void androidIndexerAvailableChanged();
 
+    void refreshDatabase();
+
 public Q_SLOTS:
 
     void databaseReady();
 
     void applicationAboutToQuit();
 
-    void showConfiguration();
-
     void setElisaApplication(ElisaApplication* elisaApplication);
 
     void playBackError(const QUrl &sourceInError, QMediaPlayer::Error playerError);
@@ -146,7 +152,7 @@ public Q_SLOTS:
 
     void connectModel(ModelDataLoader *dataLoader);
 
-    void resetMusicData();
+    void scanCollection(CollectionScan scantype);
 
     void updateSingleFileMetaData(const QUrl &url, DataTypes::ColumnsRoles role, const QVariant &data);
 
