@@ -12,7 +12,7 @@
 #include "models/datamodel.h"
 #include "models/gridviewproxymodel.h"
 
-#if KF5KIO_FOUND
+#if KFKIO_FOUND
 #include "models/filebrowsermodel.h"
 #include "models/filebrowserproxymodel.h"
 #endif
@@ -210,11 +210,6 @@ void ViewManager::openChildView(const DataTypes::MusicDataType &fullData)
         }
     }
 
-    if (lastView.mFilterType == ElisaUtils::FilterByArtist && dataType == ElisaUtils::Album && lastView.mDataFilter[DataTypes::ArtistRole].toString() != innerSecondaryTitle) {
-        nextViewParameters = lastView;
-        nextViewParameters.mDataFilter[DataTypes::ArtistRole] = innerSecondaryTitle;
-    }
-
     openViewFromData(nextViewParameters);
 }
 
@@ -289,7 +284,7 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
     {
     case FileBrowserModel:
     {
-#if KF5KIO_FOUND
+#if KFKIO_FOUND
         newModel = new ::FileBrowserModel;
         auto *realProxyModel = new FileBrowserProxyModel;
         proxyModel = realProxyModel;
@@ -479,7 +474,7 @@ int ViewManager::computePreferredSortRole(int initialValue, ElisaUtils::FilterTy
     case ElisaUtils::FilterByRecentlyPlayed:
         return DataTypes::LastPlayDate;
     case ElisaUtils::FilterByFrequentlyPlayed:
-        return DataTypes::PlayFrequency;
+        return DataTypes::PlayCounter;
     default:
         break;
     }
