@@ -44,8 +44,8 @@ public:
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::FilterByFrequentlyPlayed,
                                                ElisaUtils::Track,
-                                               DataTypes::PlayFrequency,
-                                               {DataTypes::PlayFrequency},
+                                               DataTypes::PlayCounter,
+                                               {DataTypes::PlayCounter},
                                                {i18nc("@title:menu", "Play Frequency")},
                                                Qt::DescendingOrder,
                                                {i18nc("@item:inmenu", "Least Frequently Played First"), i18nc("@item:inmenu", "Most Frequently Played First")},
@@ -274,6 +274,7 @@ void ViewsListData::setEmbeddedCategory(ElisaUtils::PlayListEntryType aEmbeddedV
         case ElisaUtils::Album:
         case ElisaUtils::Artist:
         case ElisaUtils::Genre:
+        case ElisaUtils::PlayList:
             break;
         }
     }
@@ -465,6 +466,7 @@ void ViewsListData::cleanedDatabase()
     case ElisaUtils::FileName:
     case ElisaUtils::Lyricist:
     case ElisaUtils::Container:
+    case ElisaUtils::PlayList:
         break;
     }
 }
@@ -496,6 +498,7 @@ void ViewsListData::refreshEmbeddedCategory()
     case ElisaUtils::FileName:
     case ElisaUtils::Lyricist:
     case ElisaUtils::Container:
+    case ElisaUtils::PlayList:
         break;
     }
 
@@ -524,6 +527,7 @@ void ViewsListData::refreshEmbeddedCategory()
     case ElisaUtils::FileName:
     case ElisaUtils::Lyricist:
     case ElisaUtils::Container:
+    case ElisaUtils::PlayList:
         break;
     }
 
@@ -541,6 +545,7 @@ void ViewsListData::refreshEmbeddedCategory()
     case ElisaUtils::FileName:
     case ElisaUtils::Lyricist:
     case ElisaUtils::Container:
+    case ElisaUtils::PlayList:
         break;
     }
 
@@ -610,6 +615,7 @@ void ViewsListData::refreshEmbeddedCategory()
     case ElisaUtils::FileName:
     case ElisaUtils::Lyricist:
     case ElisaUtils::Container:
+    case ElisaUtils::PlayList:
         break;
     }
 }
